@@ -8,27 +8,25 @@
  */
 static void transposing_1d_blur(unsigned char *restrict src, unsigned char *restrict dst, unsigned int width, unsigned int height, const unsigned int size)
 {
-    int j;
-    for(j=0; j < height; j++) {
+    for(unsigned int j=0; j < height; j++) {
         unsigned char *restrict row = src + j*width;
 
         // accumulate sum for pixels outside line
         unsigned int sum;
         sum = row[0]*size;
-        int i;
-        for(i=0; i < size; i++) {
+        for(unsigned int i=0; i < size; i++) {
             sum += row[i];
         }
 
         // blur with left side outside line
-        for(i=0; i < size; i++) {
+        for(unsigned int i=0; i < size; i++) {
             sum -= row[0];
             sum += row[i+size];
 
             dst[i*height + j] = sum / (size*2);
         }
 
-        for(i=size; i < width-size; i++) {
+        for(unsigned int i=size; i < width-size; i++) {
             sum -= row[i-size];
             sum += row[i+size];
 
@@ -36,7 +34,7 @@ static void transposing_1d_blur(unsigned char *restrict src, unsigned char *rest
         }
 
         // blur with right side outside line
-        for(i=width-size; i < width; i++) {
+        for(unsigned int i=width-size; i < width; i++) {
             sum -= row[i-size];
             sum += row[width-1];
 
@@ -50,16 +48,14 @@ static void transposing_1d_blur(unsigned char *restrict src, unsigned char *rest
  */
 LIQ_PRIVATE void max3(unsigned char *src, unsigned char *dst, unsigned int width, unsigned int height)
 {
-    int j;
-    for(j=0; j < height; j++) {
+    for(unsigned int j=0; j < height; j++) {
         const unsigned char *row = src + j*width,
         *prevrow = src + (j > 1 ? j-1 : 0)*width,
         *nextrow = src + MIN(height-1,j+1)*width;
 
         unsigned char prev,curr=row[0],next=row[0];
 
-        int i;
-        for(i=0; i < width-1; i++) {
+        for(unsigned int i=0; i < width-1; i++) {
             prev=curr;
             curr=next;
             next=row[i+1];
@@ -79,16 +75,14 @@ LIQ_PRIVATE void max3(unsigned char *src, unsigned char *dst, unsigned int width
  */
 LIQ_PRIVATE void min3(unsigned char *src, unsigned char *dst, unsigned int width, unsigned int height)
 {
-    int j;
-    for(j=0; j < height; j++) {
+    for(unsigned int j=0; j < height; j++) {
         const unsigned char *row = src + j*width,
         *prevrow = src + (j > 1 ? j-1 : 0)*width,
         *nextrow = src + MIN(height-1,j+1)*width;
 
         unsigned char prev,curr=row[0],next=row[0];
 
-        int i;
-        for(i=0; i < width-1; i++) {
+        for(unsigned int i=0; i < width-1; i++) {
             prev=curr;
             curr=next;
             next=row[i+1];
@@ -110,7 +104,9 @@ LIQ_PRIVATE void min3(unsigned char *src, unsigned char *dst, unsigned int width
 LIQ_PRIVATE void blur(unsigned char *src, unsigned char *tmp, unsigned char *dst, unsigned int width, unsigned int height, unsigned int size)
 {
     assert(size > 0);
-    if (width < 2*size+1 || height < 2*size+1) return;
+    if (width < 2*size+1 || height < 2*size+1) {
+        return;
+    }
     transposing_1d_blur(src, tmp, width, height, size);
     transposing_1d_blur(tmp, dst, height, width, size);
 }
