@@ -73,54 +73,68 @@ LIQ_EXPORT liq_error liq_invalid_result (liq_result *);
 
 LIQ_EXPORT liq_attr* liq_attr_create(void);
 LIQ_EXPORT liq_attr* liq_attr_create_with_allocator(void* (*malloc)(size_t), void (*free)(void*));
-LIQ_EXPORT liq_attr* liq_attr_copy(liq_attr *orig);
-LIQ_EXPORT void liq_attr_destroy(liq_attr *attr);
+LIQ_EXPORT liq_attr* liq_attr_copy(liq_attr* orig);
+LIQ_EXPORT void liq_attr_destroy(liq_attr* attr);
 
 LIQ_EXPORT liq_error liq_set_max_colors(liq_attr* attr, int colors);
-LIQ_EXPORT liq_error liq_get_max_colors_2(liq_attr* attr, int * colors);
+LIQ_EXPORT int liq_get_max_colors(liq_attr* attr);
 LIQ_EXPORT liq_error liq_set_speed(liq_attr* attr, int speed);
-LIQ_EXPORT liq_error liq_get_speed_2(liq_attr* attr, int * speed);
+LIQ_EXPORT int liq_get_speed(liq_attr* attr);
 LIQ_EXPORT liq_error liq_set_min_opacity(liq_attr* attr, int min);
-LIQ_EXPORT liq_error liq_get_min_opacity_2(liq_attr* attr, int *min);
+LIQ_EXPORT int liq_get_min_opacity(liq_attr* attr);
 LIQ_EXPORT liq_error liq_set_min_posterization(liq_attr* attr, int bits);
-LIQ_EXPORT liq_error liq_get_min_posterization_2(liq_attr* attr, int *bits);
+LIQ_EXPORT int liq_get_min_posterization(liq_attr* attr);
 LIQ_EXPORT liq_error liq_set_quality(liq_attr* attr, int minimum, int maximum);
-LIQ_EXPORT liq_error liq_get_quality(liq_attr* attr, int *minimum, int *maximum);
+LIQ_EXPORT liq_error liq_get_quality(liq_attr* attr, int* minimum, int* maximum);
 LIQ_EXPORT void liq_set_last_index_transparent(liq_attr* attr, int is_last);
 
-typedef void liq_log_callback_function(const liq_attr*, const char *message, void* user_info);
+    /* These _2 functions are for the Perl interface. They return an
+       error and the got value in the final pointer. */
+
+LIQ_EXPORT liq_error liq_get_max_colors_2(liq_attr* attr, int * colors);
+LIQ_EXPORT liq_error liq_get_speed_2(liq_attr* attr, int * speed);
+LIQ_EXPORT liq_error liq_get_min_opacity_2(liq_attr* attr, int *min);
+LIQ_EXPORT liq_error liq_get_min_posterization_2(liq_attr* attr, int *bits);
+
+typedef void liq_log_callback_function(const liq_attr*, const char* message, void* user_info);
 typedef void liq_log_flush_callback_function(const liq_attr*, void* user_info);
 LIQ_EXPORT void liq_set_log_callback(liq_attr*, liq_log_callback_function*, void* user_info);
 LIQ_EXPORT void liq_set_log_flush_callback(liq_attr*, liq_log_flush_callback_function*, void* user_info);
 
-LIQ_EXPORT liq_image *liq_image_create_rgba_rows(liq_attr *attr, void* rows[], int width, int height, double gamma);
+LIQ_EXPORT liq_image* liq_image_create_rgba_rows(liq_attr* attr, void* rows[], int width, int height, double gamma);
+LIQ_EXPORT liq_image* liq_image_create_rgba(liq_attr* attr, void* bitmap, int width, int height, double gamma);
+
+    /* Perl-interface-only function. */
+
 LIQ_EXPORT liq_error liq_image_create_rgba_rows_2(liq_attr *attr, void* rows[], int width, int height, double gamma, liq_image ** image);
-LIQ_EXPORT liq_image *liq_image_create_rgba(liq_attr *attr, void* bitmap, int width, int height, double gamma);
 
 typedef void liq_image_get_rgba_row_callback(liq_color row_out[], int row, int width, void* user_info);
-LIQ_EXPORT liq_image *liq_image_create_custom(liq_attr *attr, liq_image_get_rgba_row_callback *row_callback, void* user_info, int width, int height, double gamma);
+LIQ_EXPORT liq_image* liq_image_create_custom(liq_attr* attr, liq_image_get_rgba_row_callback* row_callback, void* user_info, int width, int height, double gamma);
 
-LIQ_EXPORT liq_error liq_image_set_memory_ownership(liq_image *image, int ownership_flags);
-LIQ_EXPORT int liq_image_get_width(const liq_image *img);
-LIQ_EXPORT int liq_image_get_height(const liq_image *img);
-LIQ_EXPORT void liq_image_destroy(liq_image *img);
+LIQ_EXPORT liq_error liq_image_set_memory_ownership(liq_image* image, int ownership_flags);
+LIQ_EXPORT int liq_image_get_width(const liq_image* img);
+LIQ_EXPORT int liq_image_get_height(const liq_image* img);
+LIQ_EXPORT void liq_image_destroy(liq_image* img);
+
+LIQ_EXPORT liq_result* liq_quantize_image(liq_attr* options, liq_image* input_image);
+
+    /* Perl-interface-only function. */
 
-LIQ_EXPORT liq_result *liq_quantize_image(liq_attr *options, liq_image *input_image);
 LIQ_EXPORT liq_error liq_quantize_image_2(liq_attr *options, liq_image *input_image, liq_result ** result_ptr);
 
-LIQ_EXPORT liq_error liq_set_dithering_level(liq_result *res, float dither_level);
+LIQ_EXPORT liq_error liq_set_dithering_level(liq_result* res, float dither_level);
 LIQ_EXPORT liq_error liq_set_output_gamma(liq_result* res, double gamma);
-LIQ_EXPORT double liq_get_output_gamma(const liq_result *result);
+LIQ_EXPORT double liq_get_output_gamma(const liq_result* result);
 
-LIQ_EXPORT const liq_palette *liq_get_palette(liq_result *result);
+LIQ_EXPORT const liq_palette* liq_get_palette(liq_result* result);
 
-LIQ_EXPORT liq_error liq_write_remapped_image(liq_result *result, liq_image *input_image, void *buffer, size_t buffer_size);
-LIQ_EXPORT liq_error liq_write_remapped_image_rows(liq_result *result, liq_image *input_image, unsigned char **row_pointers);
+LIQ_EXPORT liq_error liq_write_remapped_image(liq_result* result, liq_image* input_image, void* buffer, size_t buffer_size);
+LIQ_EXPORT liq_error liq_write_remapped_image_rows(liq_result* result, liq_image* input_image, unsigned char** row_pointers);
 
-LIQ_EXPORT double liq_get_quantization_error(liq_result *result);
-LIQ_EXPORT int liq_get_quantization_quality(liq_result *result);
+LIQ_EXPORT double liq_get_quantization_error(liq_result* result);
+LIQ_EXPORT int liq_get_quantization_quality(liq_result* result);
 
-LIQ_EXPORT void liq_result_destroy(liq_result *);
+LIQ_EXPORT void liq_result_destroy(liq_result*);
 
 #ifdef __cplusplus
 }
