@@ -45,8 +45,7 @@ static f_pixel box_variance(const hist_item achv[], const struct box *box)
     f_pixel mean = box->color;
     double variancea=0, variancer=0, varianceg=0, varianceb=0;
 
-    int i;
-    for(i = 0; i < box->colors; ++i) {
+    for(unsigned int i = 0; i < box->colors; ++i) {
         f_pixel px = achv[box->ind + i].acolor;
         double weight = achv[box->ind + i].adjusted_weight;
         variancea += variance_diff(mean.a - px.a, 2.0/256.0)*weight;
@@ -68,8 +67,7 @@ static double box_max_error(const hist_item achv[], const struct box *box)
     f_pixel mean = box->color;
     double max_error = 0;
 
-    int i;
-    for(i = 0; i < box->colors; ++i) {
+    for(unsigned int i = 0; i < box->colors; ++i) {
         const double diff = colordifference(mean, achv[box->ind + i].acolor);
         if (diff > max_error) {
             max_error = diff;
@@ -199,8 +197,7 @@ static double prepare_sort(struct box *b, hist_item achv[])
 
     qsort(channels, 4, sizeof(channels[0]), comparevariance);
 
-    int i;
-    for(i=0; i < b->colors; i++) {
+    for(unsigned int i=0; i < b->colors; i++) {
         const float *chans = (const float *)&achv[b->ind + i].acolor;
         // Only the first channel really matters. When trying median cut many times
         // with different histogram weights, I don't want sort randomness to influence outcome.
@@ -213,8 +210,7 @@ static double prepare_sort(struct box *b, hist_item achv[])
     // box will be split to make color_weight of each side even
     const unsigned int ind = b->ind, end = ind+b->colors;
     double totalvar = 0;
-    int j;
-    for(j=ind; j < end; j++) totalvar += (achv[j].color_weight = color_weight(median, achv[j]));
+    for(unsigned int j=ind; j < end; j++) totalvar += (achv[j].color_weight = color_weight(median, achv[j]));
     return totalvar / 2.0;
 }
 
@@ -239,8 +235,7 @@ static f_pixel get_median(const struct box *b, hist_item achv[])
 static int best_splittable_box(struct box* bv, unsigned int boxes, const double max_mse)
 {
     int bi=-1; double maxsum=0;
-    int i;
-    for(i=0; i < boxes; i++) {
+    for(unsigned int i=0; i < boxes; i++) {
         if (bv[i].colors < 2) continue;
 
         // looks only at max variance, because it's only going to split by it
@@ -267,7 +262,7 @@ inline static double color_weight(f_pixel median, hist_item h)
     return sqrt(diff) * (sqrt(1.0+h.adjusted_weight)-1.0);
 }
 
-static colormap *colormap_from_boxes(struct box* bv, unsigned int boxes, hist_item *achv);
+static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int boxes, hist_item *achv);
 static void adjust_histogram(hist_item *achv, const colormap *map, const struct box* bv, unsigned int boxes);
 
 double box_error(const struct box *box, const hist_item achv[])
@@ -275,8 +270,7 @@ double box_error(const struct box *box, const hist_item achv[])
     f_pixel avg = box->color;
 
     double total_error=0;
-    int i;
-    for (i = 0; i < box->colors; ++i) {
+    for (unsigned int i = 0; i < box->colors; ++i) {
         total_error += colordifference(avg, achv[box->ind + i].acolor) * achv[box->ind + i].perceptual_weight;
     }
 
@@ -289,8 +283,7 @@ static bool total_box_error_below_target(double target_mse, struct box bv[], uns
     target_mse *= hist->total_perceptual_weight;
     double total_error=0;
 
-    int i;
-    for(i=0; i < boxes; i++) {
+    for(unsigned int i=0; i < boxes; i++) {
         // error is (re)calculated lazily
         if (bv[i].total_error >= 0) {
             total_error += bv[i].total_error;
@@ -298,7 +291,7 @@ static bool total_box_error_below_target(double target_mse, struct box bv[], uns
         if (total_error > target_mse) return false;
     }
 
-    for(i=0; i < boxes; i++) {
+    for(unsigned int i=0; i < boxes; i++) {
         if (bv[i].total_error < 0) {
             bv[i].total_error = box_error(&bv[i], hist->achv);
             total_error += bv[i].total_error;
@@ -314,7 +307,7 @@ static bool total_box_error_below_target(double target_mse, struct box bv[], uns
  ** on Paul Heckbert's paper, "Color Image Quantization for Frame Buffer
  ** Display," SIGGRAPH 1982 Proceedings, page 297.
  */
-LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, unsigned int newcolors, const double target_mse, const double max_mse)
+LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, unsigned int newcolors, const double target_mse, const double max_mse, void* (*malloc)(size_t), void (*free)(void*))
 {
     hist_item *achv = hist->achv;
     struct box bv[newcolors];
@@ -329,8 +322,7 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
     bv[0].max_error = box_max_error(achv, &bv[0]);
     bv[0].sum = 0;
     bv[0].total_error = -1;
-    int i;
-    for(i=0; i < bv[0].colors; i++) bv[0].sum += achv[i].adjusted_weight;
+    for(unsigned int i=0; i < bv[0].colors; i++) bv[0].sum += achv[i].adjusted_weight;
 
     unsigned int boxes = 1;
 
@@ -344,7 +336,8 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
     while (boxes < newcolors) {
 
         if (boxes == subset_size) {
-            representative_subset = colormap_from_boxes(bv, boxes, achv);
+            representative_subset = pam_colormap(boxes, malloc, free);
+            set_colormap_from_boxes(representative_subset, bv, boxes, achv);
         }
 
         // first splits boxes that exceed quality limit (to have colors for things like odd green pixel),
@@ -381,8 +374,7 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
          */
         double sm = bv[bi].sum;
         double lowersum = 0;
-        int i;
-        for(i=0; i < break_at; i++) lowersum += achv[indx + i].adjusted_weight;
+        for(unsigned int i=0; i < break_at; i++) lowersum += achv[indx + i].adjusted_weight;
 
         const f_pixel previous_center = bv[bi].color;
         bv[bi].colors = break_at;
@@ -406,14 +398,16 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
         }
     }
 
-    colormap *map = colormap_from_boxes(bv, boxes, achv);
+    colormap *map = pam_colormap(boxes, malloc, free);
+    set_colormap_from_boxes(map, bv, boxes, achv);
+
     map->subset_palette = representative_subset;
     adjust_histogram(achv, map, bv, boxes);
 
     return map;
 }
 
-static colormap *colormap_from_boxes(struct box* bv, unsigned int boxes, hist_item *achv)
+static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int boxes, hist_item *achv)
 {
     /*
      ** Ok, we've got enough boxes.  Now choose a representative color for
@@ -423,30 +417,22 @@ static colormap *colormap_from_boxes(struct box* bv, unsigned int boxes, hist_it
      ** the box - this is the method specified in Heckbert's paper.
      */
 
-    colormap *map = pam_colormap(boxes);
-
-    int bi;
-    for(bi = 0; bi < boxes; ++bi) {
+    for(unsigned int bi = 0; bi < boxes; ++bi) {
         map->palette[bi].acolor = bv[bi].color;
 
         /* store total color popularity (perceptual_weight is approximation of it) */
         map->palette[bi].popularity = 0;
-        int i;
-        for(i=bv[bi].ind; i < bv[bi].ind+bv[bi].colors; i++) {
+        for(unsigned int i=bv[bi].ind; i < bv[bi].ind+bv[bi].colors; i++) {
             map->palette[bi].popularity += achv[i].perceptual_weight;
         }
     }
-
-    return map;
 }
 
 /* increase histogram popularity by difference from the final color (this is used as part of feedback loop) */
 static void adjust_histogram(hist_item *achv, const colormap *map, const struct box* bv, unsigned int boxes)
 {
-    int bi;
-    for(bi = 0; bi < boxes; ++bi) {
-        int i;
-        for(i=bv[bi].ind; i < bv[bi].ind+bv[bi].colors; i++) {
+    for(unsigned int bi = 0; bi < boxes; ++bi) {
+        for(unsigned int i=bv[bi].ind; i < bv[bi].ind+bv[bi].colors; i++) {
             achv[i].adjusted_weight *= sqrt(1.0 +colordifference(map->palette[bi].acolor, achv[i].acolor)/4.0);
             achv[i].likely_colormap_index = bi;
         }
@@ -459,8 +445,7 @@ static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], const fl
     float maxa = 0;
 
     // first find final opacity in order to blend colors at that opacity
-    int i;
-    for(i = 0; i < clrs; ++i) {
+    for(unsigned int i = 0; i < clrs; ++i) {
         const f_pixel px = achv[i].acolor;
         new_a += px.a * achv[i].adjusted_weight;
         sum += achv[i].adjusted_weight;
@@ -476,7 +461,7 @@ static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], const fl
 
     sum=0;
     // reverse iteration for cache locality with previous loop
-    for(i = clrs-1; i >= 0; i--) {
+    for(int i = clrs-1; i >= 0; i--) {
         double tmp, weight = 1.0f;
         f_pixel px = achv[i].acolor;
 
